**Purpose**:
Sometimes you are running a virtual machine and are running out of space, and want to expand the operating system disk.  However, there is a recovery partition to-the-right of the operating system partition.  When this happens, you have to delete that partition in order to expand the storage space for the operating system.  

These commands can be run in a headless environment using just powershell.

**From within the VM** > Open a powershell window and run the following commands:
```powershell
diskpart # (1)
list disk # (2)
select disk 0 # (3)
list partition # (4)
select partition 4 # (5)
delete partition override # (6)
select partition 3 # (7)
extend # (8)
exit # (9)
```

1.  This opens the disk management CLI tool.
2.  This displays all disks attached to the device.
3.  Ensure this disk number corresponds to the operating system disk.  Open the Disk Management GUI if you are not 100% certain.
4.  List all partitions on the previously-selected disk.
5.  This partition number is for the partition of type "**Recovery**".  If you see a different partition with a type of "**Recovery**" use that partition number instead.
6.  This instructs the computer to delete the partition and ignore the fact that it was a recovery partition.
7.  You want to select the operating system partition now, so we can expand it.  This partition will generally be of a type "**Primary**" and be the largest size partition on the disk.
8.  This will expand the operating system partition into the unallocated space that is now available to it.
9.  Gracefully close the disk management CLI utility.

## Free Space Validation
From this point, you might want to verify the free space has been accounted for, so you can run the following command to check for free space:
```powershell
Get-Volume | Select-Object DriveLetter, FileSystem, @{Name="FreeSpace(GB)"; Expression={"{0:N2}" -f ($_.SizeRemaining / 1GB)}}, @{Name="TotalSize(GB)"; Expression={"{0:N2}" -f ($_.Size / 1GB)}}
```

!!! example "Output Example"
    ```
    DriveLetter FileSystem FreeSpace(GB) TotalSize(GB)
    ----------- ---------- ------------- -------------
              C NTFS       398.40        476.20
                FAT32      0.06          0.09
                NTFS       0.11          0.63
    ```